@@ -1,5 +1,7 @@
 package Amazon::Credentials;
+
 # - module for finding and providing AWS credentials
+
 use strict;
 use warnings;
 
@@ -92,12 +94,14 @@ use constant {  ## no critic (ProhibitConstantPragma, Capitalization)
   RANDOM_VALUE                  => 0xffffffff,
   SECONDS_IN_HOUR               => 3600,
   SECONDS_IN_MINUTE             => 60,
+  SUCCESS                       => 0,
+  FAILURE                       => 1,
   SLASH                         => q{/},
   TRUE                          => 1,
   X_AMZ_SSO_BEARER_TOKEN        => ':x-amz-sso_bearer_token',
 };
 
-our $VERSION = '1.1.22';  ## no critic (RequireInterpolation)
+our $VERSION = '1.1.23';  ## no critic (RequireInterpolation)
 
 our @EXPORT_OK
   = qw( create_passkey set_sso_credentials get_role_credentials );
@@ -621,7 +625,9 @@ sub get_creds_from_role {
 ########################################################################
   my ($self) = @_;
 
-  if ( $ENV{AWS_EC2_METADATA_DISABLED} eq 'true' ) {
+  my $aws_ec2_metadata_disabled = $ENV{AWS_EC2_METADATA_DISABLED} // EMPTY;
+
+  if ( $aws_ec2_metadata_disabled eq 'true' ) {
     $self->get_logger->debug(
       'AWS_EC2_METADATA_DISABLED is true, skipping...');
 
@@ -648,7 +654,7 @@ sub get_creds_from_role {
 
     my $rsp = $ua->request($token_req);
 
-    $self->get_logger->debug( Dumper $rsp);
+    $self->get_logger->debug( $self->safe_dumper($rsp) );
 
     if ( $rsp->is_success ) {
       $self->set_imdsv2_token( $rsp->content );
@@ -777,7 +783,9 @@ sub get_creds_from_container {
   };
 
   $creds->{error} = $EVAL_ERROR;
-  $self->get_logger->debug( "EVAL_ERROR: $EVAL_ERROR\n" . Dumper $creds);
+
+  croak $EVAL_ERROR
+    if $creds->{error};
 
   return $creds;
 }
@@ -1502,30 +1510,39 @@ sub _get_access_token {
 #######################################################################
 sub help {
 ########################################################################
+  my ($options) = @_;
 
-  print {*STDOUT} <<'END_OF_USAGE';
-amazon-credentials.sh options
+  if ( !$options->{version} ) {
+
+    print {*STDOUT} <<'END_OF_USAGE';
+amazon-credentials options
 
 Formats credentials found in env, config, SSO, role
 
 Options
 -------
---help, -h     this
---ec2, -E      get credentials from server IAM profile
---env  -e      get credentials from environment variables
---profile, -p  get credentials from profile in credentials configuration
---role, -r     get credentials from SSO role
---account, -a  use with --role, specify AWS account id
+--account, -a   use with --role, specify AWS account id
+--container, -c get credentials from container IAM role
+--ec2, -E       get credentials from EC2 IAM role
+--env  -e       get credentials from environment variables
+--help, -h      this
+--profile, -p   get credentials from profile in credentials configuration
+--role, -r      get credentials from SSO role
+--version, -v   version
 
- $ amazon-credentials.sh --profile=test
+ $ amazon-credentials --profile=test
   export AWS_ACCESS_KEY_ID=AKI*****************
   export AWS_SECRET_ACCESS_KEY=****************************************
 
  $ aws sso login
  $ amazon-credentials.sh --role my-sso-role --account 01234567890
-END_OF_USAGE
 
-  exit 0;
+END_OF_USAGE
+  }
+
+  print {*STDOUT} "v$VERSION\n";
+
+  exit SUCCESS;
 }
 
 ########################################################################
@@ -1553,17 +1570,21 @@ sub main {
 
   my %options;
 
-  if (
-    !GetOptions(
-      \%options,     'help',     'env|e', 'ec2|E',
-      'profile|p=s', 'role|r=s', 'account|a=s'
-    )
-  ) {
-    help();
-  }
+  my @option_specs = qw(
+    account|a=s
+    container|c
+    ec2|E
+    env|e
+    help
+    profile|p=s
+    role|r=s
+    version
+  );
 
-  if ( $options{help} ) {
-    help();
+  if ( !GetOptions( \%options, @option_specs )
+    || $options{help}
+    || $options{version} ) {
+    help( \%options );
   }
 
   if ( $options{role} && $options{account} ) {
@@ -1572,29 +1593,33 @@ sub main {
 
     print {*STDOUT} export_credentials($credentials);
 
-    exit 0;
+    exit SUCCESS;
   }
 
-  my @order;
+  my @order = eval {
+    return 'env'
+      if $options{env};
 
-  if ( $options{env} ) {
-    push @order, 'env';
-  }
-  elsif ( $options{ec2} ) {
-    push @order, 'ec2';
-  }
-  elsif ( $options{profile} ) {
-    push @order, 'file';
-  }
+    return 'container'
+      if $options{ec2};
+
+    return 'container'
+      if $options{container};
+
+    return 'file'
+      if $options{profile};
+
+    return split /,/xsm, DEFAULT_SEARCH_ORDER;
+  };
 
   my $creds = $self->new(
     profile => $options{profile} // EMPTY,
-    order   => ( @order ? \@order : DEFAULT_SEARCH_ORDER )
+    order   => [@order],
   );
 
   print {*STDOUT} $creds->format_credentials("export %s=%s\n");
 
-  exit 0;
+  exit SUCCESS;
 }
 
 1;
@@ -1657,7 +1682,7 @@ or pass your SSO role name and account ID...
  
 =head1 VERSION
 
-This document reverse to verion 1.1.22 of
+This document reverse to verion 1.1.23 of
 L<Amazon::Credentials>.
 
 =head1 METHODS AND SUBROUTINES
